Index: webrtc/base/timeutils.h |
diff --git a/webrtc/base/timeutils.h b/webrtc/base/timeutils.h |
index 4af0d9538f058f9d969f954cd9a7fb5620463fd7..52edbbf3245fd302ec7846890565a098ca7e9cc8 100644 |
--- a/webrtc/base/timeutils.h |
+++ b/webrtc/base/timeutils.h |
@@ -35,11 +35,11 @@ typedef uint32_t TimeStamp; |
uint32_t Time32(); |
// Returns the current time in milliseconds in 64 bits. |
-int64_t Time64(); |
+int64_t TimeMillis(); |
// Returns the current time in milliseconds. |
// TODO(honghaiz): Returns Time64 once majority of the webrtc code migrates to |
// 64-bit timestamp. |
inline uint32_t Time() { |
return Time32(); |
} |
@@ -35,11 +35,11 @@ typedef uint32_t TimeStamp; |
// Returns the current time in milliseconds. |
-// TODO(honghaiz): Returns Time64 once majority of the webrtc code migrates to |
-// 64-bit timestamp. |
+// TODO(honghaiz): Change to return TimeMillis() once majority of the webrtc |
+// code migrates to 64-bit timestamp. |
inline uint32_t Time() { |
return Time32(); |